@@ -1,30 +1,18 @@
 /*
-    Copyright 2008 Sascha Peilicke <sasch.pe@gmx.de>
+    SPDX-FileCopyrightText: 2008 Sascha Peilicke <sasch.pe@gmx.de>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "gui/mainwindow.h"
 
-#include "../kigo_version.h"
+#include "kigo_version.h"
 
 #include <KAboutData>
 #include <KCrash>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 
 #include <QApplication>
 #include <KLocalizedString>
@@ -45,13 +33,16 @@ namespace Kigo { /* This is only a Doxygen stub */ }
 int main(int argc, char *argv[])
 {
     // Fixes blurry icons with fractional scaling
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication app(argc, argv);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kigo"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kigorc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("kigoui.rc"));
     migrate.migrate();
+#endif
 
     KLocalizedString::setApplicationDomain("kigo");
 
@@ -64,7 +55,7 @@ int main(int argc, char *argv[])
                         QStringLiteral("yurchor@ukr.net"));
     aboutData.addCredit(i18n("Arturo Silva"), i18n("Default theme designer"),
                         QStringLiteral("jasilva28@gmail.com"));
-    aboutData.setHomepage(QStringLiteral("https://www.kde.org/applications/games/kigo/"));
+    aboutData.setHomepage(QStringLiteral("https://apps.kde.org/kigo"));
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
     aboutData.setDesktopFileName(QStringLiteral("org.kde.kigo"));
 
